@@ -4,11 +4,8 @@ use 5.008001;
 use Moose::Role;
 use Params::Util qw( _STRING _NONNEGINT );
 use WiX3::Exceptions;
-require WiX3::XML::ComponentRef;
-require WiX3::XML::FeatureRef;
-require WiX3::XML::MergeRef;
 
-our $VERSION = '0.009';
+our $VERSION = '0.009102';
 $VERSION =~ s/_//ms;
 
 #####################################################################
@@ -67,14 +64,17 @@ sub get_componentref_array {
 	my $count = $self->count_child_tags();
 
 	if ( $self->isa('WiX3::XML::Component') ) {
+		require WiX3::XML::ComponentRef;
 		return WiX3::XML::ComponentRef->new($self);
 	}
 
 	if ( $self->isa('WiX3::XML::Feature') ) {
+		require WiX3::XML::FeatureRef;
 		return WiX3::XML::FeatureRef->new($self);
 	}
 
 	if ( $self->isa('WiX3::XML::Merge') ) {
+		require WiX3::XML::MergeRef;
 		return WiX3::XML::MergeRef->new($self);
 	}
 
@@ -108,7 +108,11 @@ sub print_attribute {
 		return q{};
 	}
 
-	return qq{ $attribute='$value'};
+	if ( $value =~ m{[']}ms ) {
+		return qq{ $attribute="$value"};
+	} else {
+		return qq{ $attribute='$value'};
+	}
 
 } ## end sub print_attribute
 
@@ -124,11 +128,11 @@ WiX3::XML::Role::Tag - Base role for XML tags.
 
 =head1 VERSION
 
-This document describes WiX3::XML::Role::Tag version 0.009
+This document describes WiX3::XML::Role::Tag version 0.009102
 
 =head1 SYNOPSIS
 
-    # use WiX3;
+	# This is composed in to other tag classes.
 
 =head1 DESCRIPTION
 
